
# volvo_software_update
This module informs you about the latest available software update for your Volvo car.

# Usage
```
define my_volvo_update fhempy volvo_software_update URL
```

URL: e.g. https://www.volvocars.com/at/support/software-release-notes/xc40-recharge-pure-electric/2021w22
